### Sample Optimization
Cardboard Box | ParametricSoln v0.2.1
by: Charlie Taylor | March 06, 2023

PRIOR TO MAXIMIZE OPTIMIZATION
    ParametricSoln: Cardboard Box

    ====================== OPTIMIZATION DESIGN VARIABLES =======================
          name         value        minimum   maximum
             L           12            1           20 Length of Cardboard  (in)
             h            4            1            6 Height of Box  (in)

     Figure of Merit: Box Volume (Volume) = 64 cuin <== Maximize

    ========================== OPTIMIZATION CONSTRAINTS =========================
          name         value        minimum   maximum
       sysMass          0.2            0          0.5 Box Mass
    ============================================================================

AFTER MAXIMIZE OPTIMIZATION
    ParametricSoln: Cardboard Box

    ====================== OPTIMIZATION DESIGN VARIABLES =======================
          name         value        minimum   maximum
             L      19.6667            1           20 Length of Cardboard  (in)
             h            3            1            6 Height of Box  (in)

     Figure of Merit: Box Volume (Volume) = 246 cuin <== Maximize

    ========================== OPTIMIZATION CONSTRAINTS =========================
          name         value        minimum   maximum
       sysMass          0.5            0          0.5 Box Mass
    ============================================================================

System Sensitivity
Design Variables (nominal values)
Name | Value | Units | Description
L | 19.6667 | in | Length of Cardboard (in)
W | 12 | in | Width of Cardboard (in)
h | 3 | in | Height of Box (in)
thk | 0.1 | in | Thickness of Cardboard (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
Volume | 246 | cuin | Box Volume (cuin) | --- | ---
sysMass | 0.5 | lbm | Box Mass (lbm) | >0 | <0.5

System Sensitivity
Design Variables (nominal values)
Name | Value | Units | Description
L | 19.6667 | in | Length of Cardboard (in)
W | 12 | in | Width of Cardboard (in)
h | 3 | in | Height of Box (in)
thk | 0.1 | in | Thickness of Cardboard (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
Volume | 246 | cuin | Box Volume (cuin) | --- | ---
sysMass | 0.5 | lbm | Box Mass (lbm) | >0 | <0.5

Design Variables (nominal values)
Name | Value | Units | Description
W | 12 | in | Width of Cardboard (in)
thk | 0.1 | in | Thickness of Cardboard (in)

Design Variables (nominal values)
Name | Value | Units | Description
L | 19.6667 | in | Length of Cardboard (in)
thk | 0.1 | in | Thickness of Cardboard (in)

Design Variables (nominal values)
Name | Value | Units | Description
L | 19.6667 | in | Length of Cardboard (in)
thk | 0.1 | in | Thickness of Cardboard (in)

Design Variables (nominal values)
Name | Value | Units | Description
W | 12 | in | Width of Cardboard (in)
thk | 0.1 | in | Thickness of Cardboard (in)

Design Variables (nominal values)
Name | Value | Units | Description
W | 12 | in | Width of Cardboard (in)
h | 3 | in | Height of Box (in)
thk | 0.1 | in | Thickness of Cardboard (in)

Design Variable Summary
Design Variables (nominal values)
Name | Value | Units | Description
L | 19.6667 | in | Length of Cardboard (in)
W | 12 | in | Width of Cardboard (in)
h | 3 | in | Height of Box (in)
thk | 0.1 | in | Thickness of Cardboard (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
Volume | 246 | cuin | Box Volume (cuin) | --- | ---
sysMass | 0.5 | lbm | Box Mass (lbm) | >0 | <0.5

    Parametric Solutions
    parasol v0.2.1
    contact: C. Taylor, cet@appliedpython.com